@@ -1,3 +1,3 @@
 from torchimize.functions.gna_fun import lsq_gna
 from torchimize.functions.lma_fun import lsq_lma
-from torchimize.functions.gna_fun_parallel import lsq_gna_parallel
+from torchimize.functions.gna_fun_parallel import lsq_gna_parallel, lsq_gna_parallel_plain
